<?php

App::uses('AppController', 'Controller');

class EvCaseStudiesAppController extends AppController {

/**
 * Constructor.
 *
 * @param CakeRequest $Request Request object for this controller. Can be null for testing,
 *  but expect that features that use the request parameters will not work.
 * @param CakeResponse $Response Response object for this controller.
 * @return void
 */
	public function __construct(CakeRequest $Request, CakeResponse $Response) {
		parent::__construct($Request, $Response);

		// add the plugins helper
		$this->helpers[] = 'EvCaseStudies.CaseStudies';
	}

	public function beforeFilter() {
		parent::beforeFilter();

		$this->CaseStudiesWidgets = $this->Components->load('EvCaseStudies.CaseStudiesWidgets');
	}

	public function widgetLatestCaseStudies($limit = 3) {
		$latestCaseStudies = $this->CaseStudiesWidgets->latestCaseStudies($limit);

		$view = new View($this, false);
		$view->loadHelper('Routable.Route');
		$view->set('latestCaseStudies', $latestCaseStudies);
		$output = $view->render('EvCaseStudies.Widgets/latest_case_studies', false);

		$this->set('caseStudiesPluginWidgetLatestCaseStudies', $output);
	}

	public function widgetCategories($limit = null) {
		$categories = $this->CaseStudiesWidgets->categories($limit);

		$view = new View($this, false);
		$view->loadHelper('Routable.Route');
		$view->set('categories', $categories);
		$output = $view->render('EvCaseStudies.Widgets/categories', false);

		$this->set('caseStudiesPluginWidgetCategories', $output);
	}

	/**
	 * Create a widget that filters by category
	 * @param  [integer] $limit The limit parameter for a find()
	 */
	public function widgetFilterByCategory($limit = null) {
		$categories = $this->CaseStudiesWidgets->categories($limit);

		$params = [];
		foreach ($this->request->params['named'] as $param => $value) {
			$params[$param] = $value;
		}
		$url = [
			'plugin' => $this->request->plugin,
			'controller' => $this->request->controller,
			'action' => $this->request->action
		];

		$route = array_merge($url, $params);

		$view = new View($this, false);
		$view->loadHelper('Routable.Route');
		$view->set('categories', $categories);
		$view->set('currentRoute', $route);
		$output = $view->render('EvCaseStudies.Widgets/filterByCategory', false);

		$this->set('caseStudiesPluginWidgetFilterByCategory', $output);
	}

	public function widgetFilterByDate($maxDate = null) {
		$params = [];
		foreach ($this->request->params['named'] as $param => $value) {
			$params[$param] = $value;
		}
		$url = [
			'plugin' => $this->request->plugin,
			'controller' => $this->request->controller,
			'action' => $this->request->action
		];

		$route = array_merge($url, $params);

		$view = new View($this, false);
		$view->loadHelper('Routable.Route');
		$view->set('maxDate', $maxDate);
		$view->set('currentRoute', $route);
		$output = $view->render('EvCaseStudies.Widgets/filterByDate', false);

		$this->set('caseStudiesPluginWidgetFilterByDate', $output);
	}
}
